/**
  *  \file client/dlg-draw.cc
  *  \brief Drawing-related dialogs
  *
  *  (c) 2001-2013 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/dlg-draw.h"
#include "cpluslib/assert.h"
#include "ui/uiglobal.h"
#include "ui/layout.h"
#include "ui/util.h"
#include "gfx/palette.h"
#include "ui/window.h"
#include "util/nls.h"
#include "client/marks.h"
#include "ui/widgets/statictext.h"
#include "ui/widgets/button.h"
#include "client/widgets/helpwidget.h"

/*************************** WNewDrawingDialog ***************************/

WNewDrawingDialog::WNewDrawingDialog()
    : UIWindow(_("Starchart Drawing"), UIWindow::BLUE_WINDOW, COLOR_GRAY)
{
    buildDialog();
}

WNewDrawingDialog::~WNewDrawingDialog()
{ }

void
WNewDrawingDialog::buildDialog()
{
    // VBox
    //   "What do you want to draw?"
    //   Grid
    //     P | Polygon
    //     R | Rectangle
    //     C | Circle
    //     M | Marker
    //   [Tag option...]
    //   HBox
    //     ESC, H

    setLayout(UIVBoxLayout::instance5);

    UIGroup& g2 = h.add(new UIGroup(h.add(new UIGridLayout(3))));
    UIGroup& g3 = h.add(new UIGroup(UIHBoxLayout::instance5));

    g2.add(h.add(new UIButton(LineDrawing, "P", 'p')).addStop());
    g2.add(h.add(new UIStaticText(_("Polygon: set of lines, starting here"), UIStaticText::StaticTitle)));
    g2.add(h.add(new UISpacer()));
    g2.add(h.add(new UIButton(RectangleDrawing, "R", 'r')).addStop());
    g2.add(h.add(new UIStaticText(_("Rectangle"), UIStaticText::StaticTitle)));
    g2.add(h.add(new UISpacer()));
    g2.add(h.add(new UIButton(CircleDrawing, "C", 'c')).addStop());
    g2.add(h.add(new UIStaticText(_("Circle centered here"), UIStaticText::StaticTitle)));
    g2.add(h.add(new UISpacer()));
    g2.add(h.add(new UIButton(MarkerDrawing, "M", 'm')).addStop());
    g2.add(h.add(new UIStaticText(_("Marker"), UIStaticText::StaticTitle)));
    g2.add(h.add(new UISpacer()));

    g3.add(h.add(new UIButton(-1, _("Cancel"), SDLK_ESCAPE)).addStop());
    g3.add(h.add(new UISpacer()));
    g3.add(h.add(new UIButton(_("Help"), 'h')));

    add(h.add(new UIStaticText(_("What do you want to draw into the starcharts?"),
                               UIStaticText::StaticTitle)));
    add(g2);
    add(g3);
    add(h.add(new WHelpWidget("pcc2:draw")));

    pack();
}

bool
WNewDrawingDialog::runDialog()
{
    ui_root->centerWidget(*this);
    int result = ui_root->runModal(*this);
    if (result == LineDrawing || result == RectangleDrawing || result == CircleDrawing || result == MarkerDrawing) {
        type = GDrawingType(result);
        return true;
    } else {
        return false;
    }
}

void
WNewDrawingDialog::setColor(uint8 user_color)
{
    this->user_color = user_color;
}

uint8
WNewDrawingDialog::getColor() const
{
    return user_color;
}

void
WNewDrawingDialog::setTag(atom_t tag)
{
    this->tag = tag;
}

atom_t
WNewDrawingDialog::getTag() const
{
    return tag;
}

GDrawingType
WNewDrawingDialog::getType() const
{
    return type;
}
