/**
  *  \file game/shiptype.cc
  *  \brief Starship Object Types
  *
  *  (c) 2001-2013 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "game/shiptype.h"
#include "game/struct.h"
#include "game/univ.h"
#include "game/ship.h"

static bool
isValidShipId(int index)
{
    return index > 0 && index <= NUM_SHIPS;
}

/**************************** GPlayedShipType ****************************/

GPlayedShipType::GPlayedShipType(GUniverse& univ)
    : GIndexedObjectType(NUM_SHIPS),
      univ(univ)
{ }

GShip&
GPlayedShipType::getObjectByIndex(int index)
{
    return univ.getShip(index);
}

GUniverse*
GPlayedShipType::getUniverseByIndex(int /*index*/)
{
    return &univ;
}

bool
GPlayedShipType::isValidIndex(int index) const
{
    return isValidShipId(index) && univ.getShip(index).isPlayable(GObject::ReadOnly);
}

/****************************** GAnyShipType *****************************/

GAnyShipType::GAnyShipType(GUniverse& univ)
    : GIndexedObjectType(NUM_SHIPS),
      univ(univ)
{ }

GShip&
GAnyShipType::getObjectByIndex(int index)
{
    return univ.getShip(index);
}

GUniverse*
GAnyShipType::getUniverseByIndex(int /*index*/)
{
    return &univ;
}

bool
GAnyShipType::isValidIndex(int index) const
{
    return isValidShipId(index) && univ.getShip(index).isVisible();
}

/**************************** GHistoryShipType ***************************/

GHistoryShipType::GHistoryShipType(GUniverse& univ)
    : GIndexedObjectType(NUM_SHIPS),
      univ(univ)
{ }

GShip&
GHistoryShipType::getObjectByIndex(int index)
{
    return univ.getShip(index);
}

GUniverse*
GHistoryShipType::getUniverseByIndex(int /*index*/)
{
    return &univ;
}

bool
GHistoryShipType::isValidIndex(int index) const
{
    return isValidShipId(index) && univ.getShip(index).getShipKind() != GShip::NoShip;
}
